Index: lib/core/stopwatch.dart |
diff --git a/lib/core/stopwatch.dart b/lib/core/stopwatch.dart |
index e43f52d4bac7ced5274815a6b56b7d3910e81456..2cb77a7e4bf2c96a19f7c7be3846668344a7266d 100644 |
--- a/lib/core/stopwatch.dart |
+++ b/lib/core/stopwatch.dart |
@@ -45,21 +45,20 @@ abstract class Stopwatch { |
* Returns 0 if the [Stopwatch] has never been started. |
* The elapsed number of clock ticks increases by [frequency] every second. |
*/ |
- int elapsed(); |
+ int get elapsedTicks; |
/** |
* Returns the [elapsed] counter converted to microseconds. |
*/ |
- int elapsedInUs(); |
+ int get elapsedMicroseconds; |
/** |
* Returns the [elapsed] counter converted to milliseconds. |
*/ |
- int elapsedInMs(); |
+ int get elapsedMilliseconds; |
/** |
* Returns the frequency of the elapsed counter in Hz. |
*/ |
- int frequency(); |
- |
+ int get frequency; |
} |
@@ -45,21 +45,20 @@ abstract class Stopwatch { |
/** |
- * Returns the [elapsed] counter converted to microseconds. |
+ * Returns the [elapsedTicks] counter converted to microseconds. |
*/ |
@@ -45,21 +45,20 @@ abstract class Stopwatch { |
/** |
- * Returns the [elapsed] counter converted to milliseconds. |
+ * Returns the [elapsedTicks] counter converted to milliseconds. |
*/ |